/*******************************************************************************
 * Copyright 2008 Seapine Software, Inc. All rights reserved.
 * 
 * IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (Seapine)
 * in consideration of your agreement to the following terms, and your use, installation,
 * modification or redistribution of this Software constitutes acceptance of these terms.
 * If you do not agree with these terms, please do not use, install, modify or redistribute
 * this Software.
 * 
 * In consideration of your agreement to abide by the following terms, and subject to these
 * terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
 * this original Seapine software (the Software), to use, reproduce, modify and redistribute
 * the Software, with or without modifications, in source and/or binary forms; provided that
 * if you redistribute the Software in its entirety and without modifications, you must retain
 * this notice and the following text and disclaimers in all such redistributions of the Software.
 * Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
 * or promote products derived from the Software without specific prior written permission from
 * Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
 * implied, are granted by Seapine herein, including but not limited to any patent rights that
 * may be infringed by your derivative works or by other works in which the Software may be
 * incorporated.
 * 
 * The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
 * EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
 * OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS. 
 * 
 * IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
 * REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
 * UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
 * IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/

using System;
using System.Collections.Generic;
using System.IO;
using System.Text;
using System.Xml;



namespace MSProjectSSCMAddin
{
    //Class handles the XML config file that is stored in the Project directory
    public class SCMConfig
    {

        public string CreateConfigFile(string ServerAddress, string sqlDB, string sqlUserName, string sqlPassword, string scmSrv)
        {
            XmlDocument xmldoc;
            XmlNode xmlnode;
            XmlElement RootElem;
            XmlElement ServerElem;
            XmlElement ProjElem;
            XmlElement UserElem;
            XmlElement PasswordElem;
           
            XmlText ElemText;

            string OutMsg = "";

            xmldoc = new XmlDocument();
            //let's add the XML declaration section
            xmlnode = xmldoc.CreateNode(XmlNodeType.XmlDeclaration, "", "");
            xmldoc.AppendChild(xmlnode);
            //let's add the root element
            RootElem = xmldoc.CreateElement("", "ROOT", "");
            xmldoc.AppendChild(RootElem);

            //let's add another element (child of the root)
            ServerElem = xmldoc.CreateElement("", "SQLServerAddress", "");
            ElemText = xmldoc.CreateTextNode(ServerAddress);
            ServerElem.AppendChild(ElemText);
            xmldoc.ChildNodes.Item(1).AppendChild(ServerElem);

            ProjElem = xmldoc.CreateElement("", "SQLDatabase", "");
            ElemText = xmldoc.CreateTextNode(sqlDB);
            ProjElem.AppendChild(ElemText);
            xmldoc.ChildNodes.Item(1).AppendChild(ProjElem);

            UserElem = xmldoc.CreateElement("", "SQLUserName", "");
            ElemText = xmldoc.CreateTextNode(sqlUserName);
            UserElem.AppendChild(ElemText);
            xmldoc.ChildNodes.Item(1).AppendChild(UserElem);

            PasswordElem = xmldoc.CreateElement("", "SQLPassword", "");
            ElemText = xmldoc.CreateTextNode(sqlPassword);
            PasswordElem.AppendChild(ElemText);
            xmldoc.ChildNodes.Item(1).AppendChild(PasswordElem);

            PasswordElem = xmldoc.CreateElement("", "SCMSRVPORT", "");
            ElemText = xmldoc.CreateTextNode(scmSrv);
            PasswordElem.AppendChild(ElemText);
            xmldoc.ChildNodes.Item(1).AppendChild(PasswordElem);
                        
            try
            {

                xmldoc.Save(Connect.AppPath + "\\SSCMConfig.xml");
                OutMsg = "File created";
            }
            catch (Exception f)
            {
                OutMsg = f.Message;
            }
            return OutMsg;



        }

        public string SaveChanges(string sqlSrv, string sqlDatabase, string sqlUserName, string sqlPassword, string scmSRVPort)
        {
            string OutMsg = "";
            try
            {
                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(Connect.AppPath + "\\SSCMConfig.xml");
                mCurrentNode = mDocument.DocumentElement;

                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLServerAddress");
                mCurrentNode.InnerText = sqlSrv;

                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLDatabase");
                mCurrentNode.InnerText = sqlDatabase;

                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLUserName");
                mCurrentNode.InnerText = sqlUserName;

                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLPassword");
                mCurrentNode.InnerText = sqlPassword;

                mCurrentNode = mCurrentNode.SelectSingleNode("//SCMSRVPORT");
                mCurrentNode.InnerText = scmSRVPort;

                mDocument.Save(Connect.AppPath + "\\SSCMConfig.xml");
            }
            catch (Exception f)
            {
                OutMsg = f.Message;
            }
            return (OutMsg);

        }

        //Method to check that file is there

        public bool Exists()
        {

            FileInfo configFile = new FileInfo(Connect.AppPath + "\\SSCMConfig.xml");
            if (configFile.Exists)
            {
                return (true);
            }
            else
            {
                return (false);
            }


        }

        //Methods for individual values
        //'get' methods are used to retrieve data from configuration file

        //get the SOAP server URL
        public string getSQLSRVFromFile()
        {
            string sqlSrv = "";
            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(Connect.AppPath + "\\SSCMConfig.xml");
                mCurrentNode = mDocument.DocumentElement;

                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLServerAddress");
                sqlSrv = mCurrentNode.InnerText;


            }
            catch (Exception f)
            {
            }
            return (sqlSrv);

        }
        //Set the SOAP URL

        public string getDBNameFromFile()
        {
            string sqlDBName = "";

            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(Connect.AppPath + "\\SSCMConfig.xml");
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLDatabase");
                sqlDBName = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
            }
            return (sqlDBName);


        }


        public string getSQLUserNameFromFile()
        {
            string sqlUserName = "";

            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(Connect.AppPath + "\\SSCMConfig.xml");
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLUserName");
                sqlUserName = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
            }
            return (sqlUserName);


        }

        public string getSQLPasswordFromFile()
        {
            string sqlPassword = "";

            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(Connect.AppPath + "\\SSCMConfig.xml");
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//SQLPassword");
                sqlPassword = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
            }
            return (sqlPassword);


        }

        public string getSCMSRVPortFromFile()
        {
            string sqlDBName = "";

            try
            {

                XmlDocument mDocument;
                XmlNode mCurrentNode;

                mDocument = new XmlDocument();
                mDocument.Load(Connect.AppPath + "\\SSCMConfig.xml");
                mCurrentNode = mDocument.DocumentElement;
                mCurrentNode = mCurrentNode.SelectSingleNode("//SCMSRVPORT");
                sqlDBName = mCurrentNode.InnerText;
            }
            catch (Exception f)
            {
            }
            return (sqlDBName);


        }


   
    }
}
