/*******************************************************************************
 * Copyright 2008 Seapine Software, Inc. All rights reserved.
 * 
 * IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (Seapine)
 * in consideration of your agreement to the following terms, and your use, installation,
 * modification or redistribution of this Software constitutes acceptance of these terms.
 * If you do not agree with these terms, please do not use, install, modify or redistribute
 * this Software.
 * 
 * In consideration of your agreement to abide by the following terms, and subject to these
 * terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
 * this original Seapine software (the Software), to use, reproduce, modify and redistribute
 * the Software, with or without modifications, in source and/or binary forms; provided that
 * if you redistribute the Software in its entirety and without modifications, you must retain
 * this notice and the following text and disclaimers in all such redistributions of the Software.
 * Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
 * or promote products derived from the Software without specific prior written permission from
 * Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
 * implied, are granted by Seapine herein, including but not limited to any patent rights that
 * may be infringed by your derivative works or by other works in which the Software may be
 * incorporated.
 * 
 * The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
 * EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
 * OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS. 
 * 
 * IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
 * REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
 * UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
 * IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/


using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Data.SqlClient;

namespace MSProjectSSCMAddin
{
    public partial class frmSCMConnection : Form
    {
        public sscapi sscm;
        public SCMConfig sConfig;
        public string OutMsg;

        public frmSCMConnection(sscapi passedsscapi, SCMConfig passedConfig)
        {
            InitializeComponent();
            sscm = passedsscapi;
            sConfig = passedConfig;
        }

        private void btnOK_Click(object sender, EventArgs e)
        {
            SaveValues(); this.Close();
        }
        private void SaveValues()
        {
            string OutMsg = "";
            sscm.setSQLSrv(txtSqlSrv.Text);
            sscm.setSQLDB(txtDatabase.Text);
            sscm.setSQLUserPassword(txtUserName.Text );
            sscm.setSQLUserPassword(txtPassword.Text);
            
            if (sConfig.Exists())
            {

                OutMsg = sConfig.SaveChanges(txtSqlSrv.Text, txtDatabase.Text, txtUserName.Text, txtPassword.Text,txtURL.Text );
            }
            else
            {
                OutMsg = sConfig.CreateConfigFile(txtSqlSrv.Text, txtDatabase.Text, txtUserName.Text, txtPassword.Text, txtURL.Text);
            }

            if ((OutMsg == "") || (OutMsg == "File created"))
            {
                MessageBox.Show(this, "Changes saved!", "Surround SCM Add-in");
            }

            else
            {
                MessageBox.Show("Error saving changes!\nError from system:\n" + OutMsg, "Surround SCM Add-in");
            }

        }

        private void btnCancel_Click(object sender, EventArgs e)
        {
            this.Close();
        }

        private void frmSCMConnection_Load(object sender, EventArgs e)
        {
            txtSqlSrv.Text = sConfig.getSQLSRVFromFile();
            txtDatabase.Text =  sConfig.getDBNameFromFile();
            txtUserName.Text = sConfig.getSQLUserNameFromFile();
            txtPassword.Text = sConfig.getSQLPasswordFromFile();
            txtURL.Text = sConfig.getSCMSRVPortFromFile();
              

        }

        private void btnTestConn_Click(object sender, EventArgs e)
        {
            if (txtSqlSrv.Text== "" || txtDatabase.Text== "" || txtUserName.Text == "")
            {
                MessageBox.Show("Cannot test connection until all information is provided!", "MSProjectSSCMAddin");
            }
            else
            {
                
                string connString = "server=" + txtSqlSrv.Text + ";user id=" + txtUserName.Text + ";password=" + txtPassword.Text + ";initial catalog=" + txtDatabase.Text + ";";
                //To test the connection, we'll query the db and see if we get anything
                try
                {
                    SqlConnection myConnection = new SqlConnection(connString);
                    SqlDataAdapter ad = new SqlDataAdapter("SELECT MainlineName from Mainline", myConnection);
                    DataSet ds = new DataSet();
                    ad.Fill(ds, "Mainlines");
                    if (ad == null)
                    {
                        MessageBox.Show("An error occurred while trying to test the connection", "MSProjectSSCMAddin");
                    }
                    else
                    {
                        MessageBox.Show("Connection established!", "MSProjectSSCMAddin");
                    }
                }
                catch (Exception fcc)
                {
                    if (fcc.Message.Contains("Invalid object name 'Mainline'"))
                    {
                        MessageBox.Show("Successfully connected to the server and database.\n" + "However, this does not appear to be a valid Surround SCM database", "MSProjectSSCMAddin");
                    }
                    else
                    {
                        MessageBox.Show("An error occurred while trying to test the connection.\n" + fcc.Message, "MSProjectSSCMAddin");
                    }
                }
                


            }


        }

        
    }
}