/*******************************************************************************
 * Copyright 2008 Seapine Software, Inc. All rights reserved.
 * 
 * IMPORTANT:  This Software is supplied to you by Seapine Software, Inc. (Seapine)
 * in consideration of your agreement to the following terms, and your use, installation,
 * modification or redistribution of this Software constitutes acceptance of these terms.
 * If you do not agree with these terms, please do not use, install, modify or redistribute
 * this Software.
 * 
 * In consideration of your agreement to abide by the following terms, and subject to these
 * terms, Seapine grants you a personal, non-exclusive license, under Seapine copyrights in
 * this original Seapine software (the Software), to use, reproduce, modify and redistribute
 * the Software, with or without modifications, in source and/or binary forms; provided that
 * if you redistribute the Software in its entirety and without modifications, you must retain
 * this notice and the following text and disclaimers in all such redistributions of the Software.
 * Neither the name, trademarks, service marks or logos of Seapine, Inc. may be used to endorse
 * or promote products derived from the Software without specific prior written permission from
 * Seapine.  Except as expressly stated in this notice, no other rights or licenses, express or
 * implied, are granted by Seapine herein, including but not limited to any patent rights that
 * may be infringed by your derivative works or by other works in which the Software may be
 * incorporated.
 * 
 * The Software is provided by Seapine on an "AS IS" basis.  SEAPINE MAKES NO WARRANTIES,
 * EXPRESS OR IMPLIED, INCLUDING WITHOUT LIMITATION THE IMPLIED WARRANTIES OF NON-INFRINGEMENT,
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE, REGARDING THE SOFTWARE OR ITS USE AND
 * OPERATION ALONE OR IN COMBINATION WITH YOUR PRODUCTS. 
 * 
 * IN NO EVENT SHALL SEAPINE BE LIABLE FOR ANY SPECIAL, INDIRECT, INCIDENTAL OR CONSEQUENTIAL
 * DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) ARISING IN ANY WAY OUT OF THE USE,
 * REPRODUCTION, MODIFICATION AND/OR DISTRIBUTION OF THE SOFTWARE, HOWEVER CAUSED AND WHETHER
 * UNDER THEORY OF CONTRACT, TORT (INCLUDING NEGLIGENCE), STRICT LIABILITY OR OTHERWISE, EVEN
 * IF SEAPINE HAS BEEN ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 ******************************************************************************/

using Microsoft.Office.Interop.MSProject;
using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using System.Data.Sql;

namespace MSProjectSSCMAddin
{
    public partial class scmRepo : Form
    {
        //Global vars
        public sscapi mSSCM;
        public ImageList newImageList;
        public sscapi.CRepository[] scmRepoTree;
        public sscapi.CBranch[] scmBranchTree;
        public Project myProject;
        public Microsoft.Office.Interop.MSProject.Application myApp;


        public scmRepo(sscapi passedSSCM, Project passedProject, Microsoft.Office.Interop.MSProject.Application passedApp)
        {
            InitializeComponent();
            mSSCM = passedSSCM;
            myProject = passedProject;
            myApp = passedApp;
        }

        private void scmRepo_Load(object sender, EventArgs e)
        {
            mSSCM.SetConnString();//Set SQL db connection string
            LoadBranchTrees();// Using the connection string, query the database and build the tree
            lstFiles.Columns.Add("File Name");//Add the column in the file list pane for files
            lstFiles.Columns[0].Width = 200;
            
        }
        private void tvRepoTree_AfterSelect(object sender, TreeViewEventArgs e)
        {
            //Populates the file list when a repository is selected
            string NodePath = e.Node.FullPath;
            
            string[] fileList = mSSCM.GetFilesForRepo(scmRepoTree, e.Node.FullPath);
            lstFiles.Items.Clear();
           
            for (int i = 0; i < fileList.Length; i++)
            {
                 lstFiles.Items.Add(fileList[i]);
            }
        }

        private void tvRepoTree_AfterExpand(object sender, TreeViewEventArgs e)
        {
            //Changes the image when the repo is expanded
            e.Node.ImageIndex = 0;
        }
        private void setImageLIst()
        {
            //Handling the images for the repos
            try
            {

                System.Drawing.Bitmap openrepo = Properties.Resources.baserepoopened;
                System.Drawing.Bitmap closedrepo = Properties.Resources.baserepoclosed;
                newImageList = new ImageList();
                newImageList.Images.Add(openrepo);
                newImageList.Images.Add(closedrepo);

            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }
        }

        private void tvRepoTree_AfterCollapse(object sender, TreeViewEventArgs e)
        {
            //Changes the image when the repo is collapsed
            e.Node.ImageIndex = 1;

        }

        private void cmbBranches_SelectedIndexChanged(object sender, EventArgs e)
        {


        }
        private void LoadRepoTree(string branchName, string mainlineName)
        {
            //Load the repository tree
            tvRepoTree.Nodes.Clear();
            setImageLIst();
            tvRepoTree.ImageList = newImageList;
            tvRepoTree.ImageIndex = 1;
                       
            scmRepoTree = mSSCM.GetRepoTreeForBranch(branchName, mainlineName);
            tvRepoTree.Nodes.Add(mSSCM.PopulateRepoTree(scmRepoTree));

        }
        private void LoadBranchTrees()
        {
            //Load the branch tree
            string[] Mainlines = mSSCM.GetMainlines();
            for (int i = 0; i < Mainlines.Length; i++)
            {
                scmBranchTree = mSSCM.GetBranchTreeforMainline(Mainlines[i]);
                tvBranchTree.Nodes.Add(mSSCM.PopulateBranchTree(scmBranchTree));
            }
        }

        private void btnAdd_Click(object sender, EventArgs e)
        {
            //Add sscm link to current task
            string scmFile = this.tvBranchTree.SelectedNode.Text + "//" + this.tvRepoTree.SelectedNode.FullPath + "/" + this.lstFiles.SelectedItems[0].Text;
            mSSCM.createTask(myProject, scmFile, myApp);
           
            
        }

        private void tvBranchTree_AfterSelect(object sender, TreeViewEventArgs e)
        {
            //Loads a new repo tree for the branch selected
            string branchName = e.Node.Text;
            string branchPath = e.Node.FullPath;
            string mainlineName = "";
            if (branchPath.Contains("/"))
            {
                mainlineName = branchPath.Substring(0, branchPath.IndexOf("/"));
            }
            else
            {
                mainlineName = branchName;
            }
            LoadRepoTree(branchName, mainlineName);
            lstFiles.Items.Clear();
        }

    }
}